@@ -88,6 +88,13 @@ struct _LauncherAppPrivate
 };
 
 /* Callbacks */
+static void
+on_effect_complete (ClutterActor *actor)
+{
+  if (CLUTTER_IS_ACTOR (actor))
+    clutter_actor_destroy (actor);
+}
+
 static void
 on_new_category (LauncherCatbar       *catbar,
                  LauncherMenuCategory *category,
@@ -107,8 +114,11 @@ on_new_category (LauncherCatbar       *catbar,
 
   if (CLUTTER_IS_ACTOR (priv->iconview))
   {
-    clutter_effect_fade (priv->temp, priv->iconview, 0,
-                         (ClutterEffectCompleteFunc)clutter_actor_destroy, 
+    if (cfg->low_graphics)
+      clutter_actor_destroy (priv->iconview);
+    else
+      clutter_effect_fade (priv->temp, priv->iconview, 0,
+                         (ClutterEffectCompleteFunc)on_effect_complete, 
                          NULL);
   }
 
@@ -170,20 +180,29 @@ static void
 show_launcher (LauncherWm *wm, LauncherApp *app)
 { 
   LauncherAppPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
 
   g_return_if_fail (LAUNCHER_IS_APP (app));
   priv = app->priv;
 
-  clutter_effect_fade (priv->temp, CLUTTER_ACTOR (app), 255, 
-                       (ClutterEffectCompleteFunc)ungrab,
-                       app);
+  if (cfg->low_graphics)
+  {
+    clutter_actor_set_opacity (CLUTTER_ACTOR (app), 255);
+    ungrab (CLUTTER_ACTOR (app), app);
+  }
+  else
+  {
+    clutter_effect_fade (priv->temp, CLUTTER_ACTOR (app), 255, 
+                         (ClutterEffectCompleteFunc)ungrab,
+                         app);
+  }
 }
 
-
 static void
 hide_launcher (LauncherWm *wm, WnckWindow *window, LauncherApp *app)
 {
   LauncherAppPrivate *priv;
+  LauncherConfig *cfg = launcher_config_get_default ();
 
   g_return_if_fail (LAUNCHER_IS_APP (app));
   priv = app->priv;
@@ -191,7 +210,10 @@ hide_launcher (LauncherWm *wm, WnckWindow *window, LauncherApp *app)
   if (priv->windowed)
     return;
 
-  clutter_effect_fade (priv->temp, CLUTTER_ACTOR (app), 50, NULL, NULL);
+  if (cfg->low_graphics)
+    clutter_actor_set_opacity (CLUTTER_ACTOR (app), 50);
+  else
+    clutter_effect_fade (priv->temp, CLUTTER_ACTOR (app), 50, NULL, NULL);
 
   clutter_grab_pointer (clutter_stage_get_default ());
   g_signal_connect (clutter_stage_get_default (),
@@ -357,8 +379,12 @@ static void
 load_dist_logo (LauncherApp *app)
 {
 #define DIST_DIR "/apps/netbook-launcher"
+#define DIST_DIR_LEGACY "/apps/ume-launcher"
 #define DIST_IMG DIST_DIR"/dist_image"
+#define DIST_IMG_LEGACY DIST_DIR_LEGACY"/dist_image"
 #define DIST_URL DIST_DIR"/dist_url"
+#define DIST_URL_LEGACY DIST_DIR_LEGACY"/dist_url"
+
   LauncherAppPrivate *priv = app->priv;
   LauncherConfig *cfg = launcher_config_get_default ();
   GConfClient *client = gconf_client_get_default ();
@@ -376,8 +402,17 @@ load_dist_logo (LauncherApp *app)
   imageurl = gconf_client_get_string (client, DIST_IMG, NULL);
   url = gconf_client_get_string (client, DIST_URL, NULL);
 
+  /* if new gconf key exists, use it, otherwise try legacy key */
   if (!imageurl)
-    return;
+  {
+    gconf_client_remove_dir (client, DIST_DIR, NULL);
+    gconf_client_add_dir (client, DIST_DIR_LEGACY, GCONF_CLIENT_PRELOAD_NONE, NULL);
+    imageurl = gconf_client_get_string (client, DIST_IMG_LEGACY, NULL);
+    url = gconf_client_get_string (client, DIST_URL_LEGACY, NULL);
+
+    if (!imageurl)
+      return;
+  }
 
   logo = gdk_pixbuf_new_from_file_at_scale (imageurl,
                                             width, height, TRUE, NULL);
@@ -405,12 +440,20 @@ load_dist_logo (LauncherApp *app)
   g_object_unref (client);
 }
 
+static gboolean
+deactivate_shortcut (LauncherShortcut *shortcut)
+{
+  launcher_shortcut_set_active (LAUNCHER_SHORTCUT (shortcut), FALSE);
+  return FALSE;
+}
+
 static void
 on_quit_clicked (LauncherShortcut *shortcut)
 {
   gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
                                     "gnome-session-save --kill --gui",
                                     NULL);
+  g_timeout_add_seconds (2, (GSourceFunc)deactivate_shortcut, shortcut);
 }
 
 static void
@@ -457,6 +500,7 @@ on_places_clicked (LauncherShortcut *shortcut, LauncherApp *app)
     app->name = g_strdup (launcher_shortcut_get_label (shortcut));
     app->pixbuf = launcher_shortcut_get_icon (shortcut);
     app->exec = g_strdup (clutter_actor_get_name (CLUTTER_ACTOR (shortcut)));
+    app->can_fav = FALSE;
 
     volume = g_object_get_data (G_OBJECT (shortcut), "volume");
     if (G_IS_VOLUME (volume))
@@ -464,7 +508,8 @@ on_places_clicked (LauncherShortcut *shortcut, LauncherApp *app)
 
     cat->applications = g_list_append (cat->applications, app);
   }
-
+  
+  launcher_catbar_deactivate (LAUNCHER_CATBAR (app->priv->catbar));
   on_new_category (NULL, cat, app);
 
   g_list_free (places);
